# About

`wbib` is an open project for integrating scholarly visualization via Wikidata in python.

Note: queries might change from version to version while they get improved.
New queries that inherit an old name will aim at conveying the same information
as previously, but better formatted.
Project is inspired and builds upon queries and dashboards by [Scholia](https://scholia.toolforge.org/).
